;###################################################
;# Read EDOP and CRS data products from UF files   #
;# Modified from load_edop_uf2.pro                 #
;#              Lihua Li, 11/08/2002               #
;###################################################

PRO load_uf, names, crs=crs, edop=edop

  @common-gsfc.uf

  PRINT, 'Reading file: ', filename
  OPENR, infile, filename, /GET_LUN
  maxdwell = 7300
  maxgate = 738
  nfields = n_elements(names)

  ndata = FLTARR(nfields, maxdwell, maxgate)    ; Nadir data fields
  range = INTARR(maxdwell, maxgate)
  gspeed = FLTARR(maxdwell)
  nsurfgate = INTARR(maxdwell)                  ; Nadir surface gates
  fsurfgate = INTARR(maxdwell)                  ; Forward surface gates
   
  pitch = FLTARR(maxdwell)                      ; er-2 pitch angle
  roll  = FLTARR(maxdwell)                      ; er-2 roll angle 
  drift = FLTARR(maxdwell)                      ; er-2 drift angle 
  heading = FLTARR(maxdwell)                    ; er-2 heading angle 
  lat = FLTARR(maxdwell)                        ; INS latitude [deg]
  lon = FLTARR(maxdwell)                        ; INS longitude [deg]
  alt = FLTARR(maxdwell)                        ; INS altitude  [m]
  time = FLTARR(maxdwell)                       ; INS decimal time [hours]
  t_str = STRARR(maxdwell)                      ; INS current time: hh:mm:ss GMT

  surf_p = FLTARR(maxdwell)                     ; raw power at surface gate
  surf_z = FLTARR(maxdwell)                     ; reflectivity power at surface gate  
  surf_m = FLTARR(maxdwell)                     ; power in dBm at surface gate  

  IF keyword_set(edop) THEN surf_v=FLTARR(maxdwell)

  IF keyword_set(crs) THEN BEGIN
    surf_vl = FLTARR(maxdwell)                    ; CRS velocity from low PRF at surface gate  
    surf_vh = FLTARR(maxdwell)                    ; CRS velocity from high PRF at surface gate 
    surf_vc = FLTARR(maxdwell)                    ; CRS velocity from dual PRF at surface gate 
  ENDIF 

  i = 0
 
  WHILE (EOF(infile) NE 1)  AND  (i LT maxdwell) DO  BEGIN
    ufbuf = 0
    UF_read_dwell, infile, ufbuf, /RDSS

    FOR f = 0, nfields - 1 DO  BEGIN
      radial = 0
      UFnameddata, ufbuf, names(f), radial, ngates, ERROR = status
      ndata(f, i, 0:ngates - 1) = radial
    ENDFOR

    nsurfgate(i) = UF_nadir_sgate(ufbuf, 1)     ; surface gate for surface channel
    fsurfgate(i) = UF_forward_sgate(ufbuf, 3)
    gspeed(i)    = UFedop_ins_gspeed(ufbuf)
    range(i, 0:ngates-1) = Uf_rangevec(ufbuf, 1)

    pitch(i) = UFedop_ins_pitch(ufbuf)
    roll(i)  = UFedop_ins_roll(ufbuf)
    drift(i) = UFedop_ins_drift(ufbuf)
    heading(i) = UFedop_ins_heading(ufbuf)
    lat(i)   = UFedop_ins_latitude(ufbuf)
    lon(i)   = UFedop_ins_longitude(ufbuf)
    alt(i)   = UFedop_gps_altitude(ufbuf)
    time(i)  = UFedop_ins_time(ufbuf)
    t_str(i) = UFedop_ins_strtime(ufbuf)
 
    i = i + 1

  ENDWHILE
   
  CLOSE, infile
  FREE_lun, infile
  ndwells = i 
  print, 'ndwells', ndwells, 'ngates', ngates

  ; asign data products

  for j=0, ndwells-1 do begin
     sf_gt = where(ndata(0,j,50:*) eq max(ndata(0,j,50:*)))+50
     surf_z(j)  = ndata(0,j,sf_gt)  
     surf_p(j)  = ndata(1,j,sf_gt)
     surf_m(j)  = ndata(2,j,sf_gt)

     IF keyword_set(edop) THEN surf_v(j) = ndata(3,j,sf_gt)
    
     IF keyword_set(crs) THEN BEGIN
         surf_vl(j) = ndata(3,j,sf_gt)
         surf_vh(j) = ndata(4,j,sf_gt) 
         surf_vc(j) = ndata(5,j,sf_gt)
     ENDIF

  endfor

  im_z =   FLTARR(ndwells, ngates) 
  im_p =   FLTARR(ndwells, ngates) 
  im_m =   FLTARR(ndwells, ngates) 
  
  im_z(*,*) =  ndata(0,0:ndwells-1, 0:ngates-1)
  im_p(*,*) =  ndata(1,0:ndwells-1, 0:ngates-1)
  im_m(*,*) =  ndata(2,0:ndwells-1, 0:ngates-1)

  IF keyword_set(edop) THEN BEGIN
      im_v =  FLTARR(ndwells, ngates) 
      im_v(*,*) =  ndata(3,0:ndwells-1, 0:ngates-1)
  ENDIF

  IF keyword_set(crs) THEN BEGIN
    im_vl =  FLTARR(ndwells, ngates) 
    im_vh =  FLTARR(ndwells, ngates) 
    im_vc =  FLTARR(ndwells, ngates)
    im_wl =  FLTARR(ndwells, ngates) 
    im_wh =  FLTARR(ndwells, ngates) 
    im_wc =  FLTARR(ndwells, ngates)

    im_zo =  FLTARR(ndwells, ngates)
    im_mo =  FLTARR(ndwells, ngates)
    help, im_zo, im_mo

    im_vl(*,*) = ndata(3,0:ndwells-1, 0:ngates-1)
    im_vh(*,*) = ndata(4,0:ndwells-1, 0:ngates-1)
    im_vc(*,*) = ndata(5,0:ndwells-1, 0:ngates-1)
    im_wl(*,*) = ndata(6,0:ndwells-1, 0:ngates-1)
    im_wh(*,*) = ndata(7,0:ndwells-1, 0:ngates-1)
    im_wc(*,*) = ndata(8,0:ndwells-1, 0:ngates-1)

    im_zo(*,*) = ndata(9,0:ndwells-1, 0:ngates-1) 
    im_mo(*,*) = ndata(10,0:ndwells-1, 0:ngates-1) 
  ENDIF

  ; 
  ; Trim arrays
  ;
  IF KEYWORD_SET(limit) THEN $
     ngates = max(nsurfgate) + limit
  IF ngates GT maxgate THEN ngates = maxgate

  range=range(0:ndwells,0:ngates-1)
  gspeed = gspeed(0:ndwells-1)
  ndata = ndata(*, 0:ndwells-1,0:ngates-1)
  nsurfgate = nsurfgate(0:ndwells-1)
 
  pitch = pitch(0:ndwells - 1)
  roll  = roll(0:ndwells - 1)
  drift = drift(0:ndwells - 1)
  heading = heading(0:ndwells - 1)
  lat = lat(0:ndwells - 1)
  lon = lon(0:ndwells - 1)
  alt  = alt(0:ndwells - 1)
  time = time(0:ndwells - 1)
  t_str = t_str(0:ndwells - 1)

  surf_z = surf_z(0:ndwells - 1)
  surf_p = surf_p(0:ndwells - 1)
  surf_m = surf_m(0:ndwells - 1)

  IF keyword_set(edop) THEN surf_v=surf_v(0:ndwells - 1)

  IF keyword_set(crs) THEN BEGIN
    surf_vl = surf_vl(0:ndwells - 1)
    surf_vh = surf_vh(0:ndwells - 1)
    surf_vc = surf_vc(0:ndwells - 1)
  ENDIF

  ; incidence angle
  pitch_offset=0.0  
  i_angle = atan( sqrt((tan(!dtor*roll))^2+ (tan(!dtor*(pitch+pitch_offset)))^2)) * !radeg
 
END



