;##############################################################

; FILE:   read_uf.pro
;
; USAGE:  read_uf, crs=crs, edop=edop, save_dat=save_dat
;
; KEYWORDS: crs:  set this key word for CRS data
;           edop: set this key word for EDOP data
;           save_dat: set this key word for saving data 
;                     array into a IDL dat file 
;
; ABSTRACT:  Program to read in CRS and EDOP UF format data 
;            and save into a IDL dat file
;
; AUTHOR:  Lihua Li
;          UMBC/GEST
;          NASA GSFC, Code 912
;          Greenbelt, MD 20771
;          Tel: (301) 614-6356
;          Email: lihua@gsfc.nasa.gov
;
; CREATED: Jan. 27, 2003
;
; MODIFIED:

;##############################################################

@common-gsfc.uf

PRO read_uf, crs=crs, edop=edop, save_dat=save_dat

@common-gsfc.uf
!Path=!PATH+':./uf-lib/datah:./uf-lib/edop:./uf-lib/fieldh
!Path=!PATH+':./uf-lib/manh:./uf-lib/edop/hybrid
!Path=!PATH+':./uf-lib/opth:./uf-lib/util:./uf-lib/edop/gps
!Path=!PATH+':./uf-lib/edop/ins:./uf-lib/edop/instr

  ;set paths for UF data and dat file
  uf_path ='./uf-data/'
  dat_path = './dat/'
  filename=PICKFILE(/READ, PATH=uf_path)

  pos_uf = STRPOS(filename, '.uf')

  IF keyword_set(crs) THEN BEGIN
       fields=['ZC', 'PC', 'MC', 'VL', 'VH', 'VC', 'WL','WH','WC','ZO', 'MO']
       shortname = STRMID(filename, pos_uf-20, 20)
  ENDIF

  IF keyword_set(edop) THEN BEGIN
       fields=['ZN', 'PN', 'MN', 'VN']
       shortname = STRMID(filename, pos_uf-21, 21)
  ENDIF
 
  ; read in data from uf file
  Load_uf, fields, crs=crs, edop=edop

  ;for CRS data
  IF keyword_set(crs) THEN BEGIN
     raw_p = im_m       ; dBm
     refl = im_z        ; dBZe
     vel  = im_vh       ; m/s
     sw = im_wh
     gspace = 37.5 
     range0 = -112.5    ; range of the first gate
  ENDIF

  IF keyword_set(edop) THEN BEGIN
     refl = im_z
     vel  = im_v
     gspace = 37.5
     range0 = 1000.0 

     pos = STRPOS(filename, '/EDOP')
     shortname = STRMID(filename, pos+1, 14)  
  ENDIF

  IF keyword_set(save_dat) THEN BEGIN
     save_file = dat_path+ shortname+'.dat' 
     print, 'saving variables in file ', save_file
     save, filename=save_file, lat, lon, alt, time, t_str, $
                    raw_p, refl, vel, sw, gspace, range0
  ENDIF

END



