;
;==========================================================================
;
; FILE: ufrangezero.pro
;
; USAGE:  result = UFrangezero(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the total range to the first gate in kilometers for the
;           Nth field in the UF dwell buffer
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the range in kilometers to the center of the first gate for the
; Nth field
;
FUNCTION UFrangezero, dwell, n
  RETURN, UFrzero(dwell, n) + (UFcenteradj(dwell, n) / 1000.0)
END
