;
;==========================================================================
;
; FILE: ufthreshold.pro
;
; USAGE:  result = UFthreshold(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the scaled value of the data used to threshold the
;           Nth field
;           Note that the threshold data can be different units from the
;           Nth field (see UFthresholdname)
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the threshold value used with the Nth field
; Error = -1
;
FUNCTION UFthreshold, dwell, n
  d = UFfieldhdr(dwell, n)
  IF (d EQ -1) THEN  BEGIN
    RETURN, -1
  ENDIF
  RETURN, float(dwell(d + 14)) / UFtscale(dwell)
END
