;
;==========================================================================
;
; FILE: ufedop_gps_latitude.pro
;
; USAGE:  result = UFedop_gps_latitude(ufbuf)
;         ARGUMENT  ufbuf   Buffer of UF words for a dwell of radar data
;
; ABSTRACT: Return ER-2 GPS latitude in degrees from the EDOP Local Use
;           header
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return GPS latitude in degrees
;
FUNCTION UFedop_gps_latitude, dwell
  i = UFedop_gps(dwell)
  deg = float(dwell(i + 6))
  deg = deg + float(dwell(i + 7)) / 60.0 
  deg = deg + float(dwell(i + 8)) / 230400.0
  RETURN, deg
END
