;
;==========================================================================
;
; FILE: ufedop_gps_time.pro
;
; USAGE:  result = UFedop_gps_time(ufbuf)
;         ARGUMENT  ufbuf   Buffer of UF words for a dwell of radar data
;
; ABSTRACT: Return GPS time as decimal hours from the EDOP Local Use header
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the current GPS time in decimal hours
;
FUNCTION UFedop_gps_time, dwell
  i = UFedop_gps(dwell)
  hour = float(dwell(i + 12))
  hour = hour + float(dwell(i + 13)) / 60.0
  hour = hour + float(dwell(i + 14)) / 3600.0
  RETURN, hour
END
