;
;==========================================================================
;
; FILE: uffieldhdr.pro
;
; USAGE:  result = UFfieldhdr(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the index for the Nth data field header for a UF dwell
;           Note that the index assumes unit origin indexing
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the index of the Field header for the Nth parameter
;
FUNCTION UFfieldhdr, dwell, n
  d = UFdatahdr(dwell)
  IF (n GT dwell(d)) THEN BEGIN
    print, "FIELD IS TOO LARGE"
    RETURN, -1
  ENDIF
  RETURN, dwell(d + 4 + (n - 1)*2)
END
