;
;==========================================================================
;
; FILE: ufblazimuth.pro
;
; USAGE:  result = UFblazimuth(ufbuf)
;         ARGUMENTS  ufbuf  Buffer of UF words for a radar dwell
;
; ABSTRACT: Return the baseline azimuth in degrees for a UF dwell
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the baseline azimuth in degrees
;
FUNCTION UFblazimuth, dwell
  d = UFoptionalhdr(dwell)
  IF dwell(d + 4) NE UFbaddata(dwell) THEN  $
    RETURN, float(dwell(d + 4)) / 64.0  $
  ELSE  $
    RETURN, UFbaddata(dwell)
END
