;
;==========================================================================
;
; FILE: uf_acdoppler.pro
;
; USAGE: result = UF_acdoppler(ufbuf, name [, /OLD])
;        ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                   name   2 character ASCII name of the data field
;                   /OLD   Use for UF files created PRIOR to January 1996
;
; ABSTRACT: Return the radial component of the ER-2 motion.  This value is
;           used to correct the raw Doppler velocity for aircraft motion.
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 8 November 1995
;
; MODIFIED: 29 December 1995 - IJC
;           Added /OLD keyword for UF files prior to January 1996
;           and updated ER-2 velocity component for 4th word
;
;==========================================================================
;


;
; For the named field, return the ER-2 velocity value used to correct the
; raw Doppler data for aircraft motion.  Units are m/s.
; Error = -1
;
FUNCTION UF_acdoppler, dwell, name, OLD = old
  velocity = -1
  ;
  ; Get the logical field number
  ;
  field = UFfieldnumber(dwell, name)
  IF KEYWORD_SET(old) THEN BEGIN
    ;
    ; If there is a word in the field specific area and the named field
    ; exists then convert the velocity
    ;
    IF (UFspword_size(dwell, field) GE 1  AND  field NE -1) THEN  $
      velocity = FLOAT(dwell(UFspwords(dwell, field))) / UFdatascale(dwell, field)
  ENDIF ELSE BEGIN
    IF (UFspword_size(dwell, field) GE 4  AND  field NE -1) THEN  $
      velocity = FLOAT(dwell(UFspwords(dwell, field) + 3)) / UFdatascale(dwell, field)
  ENDELSE
;
  RETURN, velocity
END
